@@ -6,6 +6,7 @@
 #' @param missing logical: if TRUE, missing data is considered; FALSE only uses complete cases.
 #' @param overall logical: if TRUE, an overall column is included.
 #' @param comparison logical: if TRUE, a comparison test is conducted between columns.
+#' @param digits The default number of digits to use in the table. By default, the package will use 2 significant digits.
 #' @param default_num_summary The default summary function to use for numerical rows. By default, the package will use `num_default()`, but the user can also choose `num_minmax`, `num_medianiqr`, `num_mean_sd`, or write a custom function to use for the rows.
 #' @param default_cat_summary The default summary function to use for categorical rows. By default, the package will use `cat_default()`, but the user can also choose `cat_pct` or write a custom function to use for the rows.
 #' @param default_binary_summary The default summary function to use for binary rows. By default, the package will use `binary_default()`, but the user can also choose `binary_pct` or write a custom function to use for the rows.
@@ -22,6 +23,7 @@ tbl_start <- function(
   , missing = FALSE
   , overall = TRUE
   , comparison = FALSE
+  , digits = 2
   , default_num_summary = num_default
   , default_cat_summary = cat_default
   , default_binary_summary = binary_default
@@ -41,6 +43,7 @@ tbl_start <- function(
               overall = overall, 
               comparison = comparison, 
               num_col = num_col,
+              digits = digits,
               default_num_summary = default_num_summary,
               default_cat_summary = default_cat_summary,
               default_binary_summary = default_binary_summary)
